# $Id: europe.rb,v 1.8 2006/04/10 10:18:21 ianmacd Exp $
#

module Finance
  class Quote
    module Yahoo

      # = Fetch quotes from Yahoo Europe.
      #
      #  require 'finance/quote'
      #
      #  q = Finance::Quote.new
      #  qd = q.fetch( 'europe', '12150.PA' )
      #  qd = q.fetch( 'yahoo_europe', '12150.PA' )  # alternative form
      #
      # This module fetches information from Yahoo Europe. Symbols should be
      # provided in the format <b>SYMBOL.EXCHANGE</b>, where the exchange code
      # is one of the following:
      #
      #  PA - Paris
      #  BC - Barcelona
      #  BE - Berlin
      #  BI - Bilbao
      #  BR - Breme
      #  CO - Copenhagen
      #  D  - Dusseldorf
      #  F  - Frankfurt
      #  H  - Hamburg
      #  HA - Hanover
      #  L  - London
      #  MA - Madrid
      #  MC - Madrid (M.C.)
      #  MI - Milan
      #  MU - Munich
      #  O  - Oslo
      #  ST - Stockholm
      #  SG - Stuttgart
      #  VA - Valence
      #  DE - Xetra (was FX)
      #
      # Stocks are returned in the currency of the local exchange. You can set
      # the <em>@currency</em> attribute of your Finance::Quote object to
      # change the currency in which information is returned.
      #
      # Information obtained by this module may be covered by Yahoo's terms
      # and conditions. See http://uk.finance.yahoo.com/ for more details.
      #
      module Europe

	Finance::Quote::register_plugin( self,
					{ :europe => :yahoo_europe,
					  :yahoo_europe => :yahoo_europe } )

	# URL from where to obtain information.
	YAHOO_EUROPE_URL = 'http://uk.finance.yahoo.com/d/quotes.csv'

	def yahoo_europe( *symbols )
	  symbols.flatten!
	  info = yahoo_request( YAHOO_EUROPE_URL, symbols )

	  symbols.each do |symbol|
	    next unless info[symbol][:success]

	    info[symbol][:method] = :yahoo_europe
	  end

	  return info
	end

      end
    end
  end
end
