# $Id: usa.rb,v 1.8 2007/10/09 00:48:06 ianmacd Exp $
#

module Finance
  class Quote
    module Yahoo

      # = Fetch quotes from Yahoo USA.
      #
      #  require 'finance/quote'
      #
      #  q = Finance::Quote.new
      #  qd = q.fetch( 'usa', 'CRM' )
      #
      # This module provides access to information from a number of exchanges
      # in the USA and Canada, using Yahoo USA as its source. The following
      # exchanges are available:
      #
      #  canada
      #  usa
      #  yahoo
      #  nyse
      #  nasdaq
      #  vanguard
      #  fidelity
      #
      # These exchanges all use the same information source and can thus be
      # considered somewhat interchangable. However, *yahoo* should be passed
      # to _fetch_ if you wish to obtain information from any source that
      # Yahoo tracks.
      #
      # Note that Yahoo makes no distinction between the various exchanges in
      # the USA and Canada. For example, it is possible to request a stock
      # using the _NYSE_ exchange and obtain data even if that stock
      # does exists on a different exchange from the NYSE.
      #
      # Information returned by this module may be subject to Yahoo's terms
      # and conditions. See http://finance.yahoo.com/ for more information.
      #
      module USA

	Finance::Quote::register_plugin( self,
	  { :canada   => :yahoo,
	    :usa      => :yahoo,
	    :nyse     => :yahoo,
	    :nasdaq   => :yahoo,
	    :vanguard => :yahoo,
	    :fidelity => :yahoo_fidelity
	  }
	)

	# URL from where to obtain information.
	YAHOO_URL = 'http://download.finance.yahoo.com/d'

	#--
	# This list should really be common for both fidelity.rb and this
	# module. We could possibly get away with checking for /XX$/, but it
	# is unknown how reliable that is.
	#++
	#
	YIELD_FUNDS = { :FDRXX => 1,
			:FDTXX => 1,
			:FGMXX => 1,
			:FRTXX => 1,
			:SPRXX => 1,
			:SPAXX => 1,
			:FDLXX => 1,
			:FGRXX => 1
		      }

	def yahoo_fidelity( symbols )
	  info = yahoo( symbols )

	  symbols.each do |symbol|
	    next unless info[symbol][:success]

	    if YIELD_FUNDS[symbol]
	      info[symbol][:yield] = info[symbol][:price]
	    else
	      info[symbol][:nav] = info[symbol][:price]
	    end
	  end

	  return info
	end

	def yahoo( *symbols )
	  symbols.flatten!
	  info = yahoo_request( YAHOO_URL, symbols )

	  symbols.each do |symbol|
	    next unless info[symbol][:success]

	    info[symbol][:method] = :yahoo
	  end

	  return info
	end

      end
    end
  end
end
